# -*-makefile-*-
#
# Copyright (C) 2010 by Juergen Kilb
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_GRAPHICS_SDK) += graphics_sdk

#
# Paths and names
#
GRAPHICS_SDK_VERSION	:= 4_04_00_02
GRAPHICS_SDK_MD5	:= 901327765c0991900afda91473f84725
GRAPHICS_SDK		:= Graphics_SDK_setuplinux_$(GRAPHICS_SDK_VERSION)
GRAPHICS_SDK_SUFFIX	:= bin
GRAPHICS_SDK_SOURCE	:= $(SRCDIR)/$(GRAPHICS_SDK).$(GRAPHICS_SDK_SUFFIX)
GRAPHICS_SDK_URL	:= http://software-dl.ti.com/dsps/dsps_public_sw/sdo_sb/targetcontent/gfxsdk/$(GRAPHICS_SDK_VERSION)/exports/$(GRAPHICS_SDK).$(GRAPHICS_SDK_SUFFIX)
GRAPHICS_SDK_DIR	:= $(BUILDDIR)/$(GRAPHICS_SDK)
GRAPHICS_SDK_LICENSE	:= unknown

ifdef PTXCONF_GRAPHICS_SDK 
$(STATEDIR)/kernel.targetinstall.post: $(STATEDIR)/graphics_sdk.targetinstall
$(STATEDIR)/qt4.prepare: $(STATEDIR)/graphics_sdk.install
endif

OMAPES := x.x
ifdef PTXCONF_GRAPHICS_SDK_OMAPES_2X
	OMAPES := 2.x
endif
ifdef PTXCONF_GRAPHICS_SDK_OMAPES_3X
	OMAPES := 3.x
endif
ifdef PTXCONF_GRAPHICS_SDK_OMAPES_5X
	OMAPES := 5.x
endif
ifdef PTXCONF_GRAPHICS_SDK_OMAPES_6X
	OMAPES := 6.x
endif
ifdef PTXCONF_GRAPHICS_SDK_OMAPES_7X
	OMAPES := 7.x
endif

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

$(GRAPHICS_SDK_SOURCE):
	@$(call targetinfo)
	@wget --output-document=$(GRAPHICS_SDK_SOURCE) $(GRAPHICS_SDK_URL)
	@chmod a+x $(GRAPHICS_SDK_SOURCE)
# ----------------------------------------------------------------------------
# Extract 
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_sdk.extract:
	@$(call targetinfo)
	@$(call clean, $(GRAPHICS_SDK_DIR))
	magic(){ sh -c "$(GRAPHICS_SDK_SOURCE) 							\
				--mode console 							\
				--prefix $(GRAPHICS_SDK_DIR)					\
				--es$(OMAPES)							\
				--sdk "; };							\
	[ -d $(GRAPHICS_SDK_DIR) ] || mkdir -p $(GRAPHICS_SDK_DIR);				\
	cd $(GRAPHICS_SDK_DIR)	; 								\
	case $$? in										\
	(0) 											\
		echo "extracting graphics sdk shell archive (pwd is `pwd`)";			\
		echo -e "Y\n q"									\
		"$(call remove_quotes,$(PTXCONF_GRAPHICS_SDK_LICENSE_ACCEPT_STRING))" | magic ;	\
	;;											\
	(*)	echo "an error occurred"; exit 1 ;						\
	;;											\
	esac
	@$(call patchin, GRAPHICS_SDK)
	@$(call touch)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------
GRAPHICS_SDK_PATH	:= PATH=$(CROSS_PATH)
GRAPHICS_SDK_ENV	:= $(CROSS_ENV)
BUILD 			:= release
GRAPHICS_SDK_BASEDIR 	:= $(SYSROOT)/opt/gfxlibraries/gfx_rel_es$(OMAPES)

ifdef PTXCONF_GRAPHICS_SDK_DEBUG
	BUILD := debug
	GRAPHICS_SDK_BASEDIR := $(SYSROOT)/opt/gfxlibraries/gfx_dbg_es$(OMAPES)
endif

#guide qt4 to lib and header
QT4_QMAKE_LIBS_OPENGL_ES1	:= -lGLES_CM
QT4_QMAKE_LIBS_OPENGL_ES1CL	:= -lGLES_CM
QT4_QMAKE_LIBS_OPENGL_ES2	:= -lGLESv2\
			\nQMAKE_LIBS_OPENVG = -lOpenVG -lOpenVGU\
			\nQMAKE_INCDIR_OPENVG = $(GRAPHICS_SDK_DIR)/GFX_Linux_SDK/OVG/SDKPackage/Builds/OVG/Include $(GRAPHICS_SDK_DIR)/GFX_Linux_SDK/OVG/SDKPackage/Builds/OVG/Include/VG 
# -lsrv_um -lIMGegl

$(STATEDIR)/graphics_sdk.prepare:
	@$(call targetinfo)
	@$(call touch)

# ----------------------------------------------------------------------------
#  Compile:
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_sdk.compile:

	@$(call targetinfo)
	cd $(GRAPHICS_SDK_DIR) && $(GRAPHICS_SDK_PATH) $(MAKE) \
		BUILD=$(BUILD) \
		GRAPHICS_INSTALL_DIR=$(GRAPHICS_SDK_DIR) \
		OMAPES=$(OMAPES) \
		HOME=$(BUILDDIR) \
		CSTOOL_PREFIX=$(PTXCONF_COMPILER_PREFIX) \
		CSTOOL_DIR=$(PTXDIST_WORKSPACE)/selected_toolchain \
		CROSS_COMPILE=$(PTXCONF_COMPILER_PREFIX) \
		KERNEL_INSTALL_DIR=$(KERNEL_DIR) \
		PLAT_CC=$(CROSS_CC) \
		PLAT_CPP=$(CROSS_CXX) \
		PLAT_AR=$(CROSS_AR) \
		TOOLCHAIN=$(PTXDIST_WORKSPACE)/selected_toolchain \
		all
	@$(call touch)
# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_sdk.install:

	@$(call targetinfo)
	install -d $(SYSROOT)/etc/init.d
	cd $(GRAPHICS_SDK_DIR) && $(GRAPHICS_SDK_PATH) $(MAKE) \
		BUILD=$(BUILD) \
		OMAPES=$(OMAPES) \
		HOME=$(BUILDDIR) \
		CSTOOL_PREFIX=$(PTXCONF_COMPILER_PREFIX) \
		CROSS_COMPILE=$(PTXCONF_COMPILER_PREFIX) \
		KERNEL_INSTALL_DIR=$(KERNEL_DIR) \
		GRAPHICS_INSTALL_DIR=$(GRAPHICS_SDK_DIR) \
		TARGETFS_INSTALL_DIR=$(SYSROOT) install

	install -d $(SYSROOT)/include
	install -d $(SYSROOT)/include/GLES
	install -d $(SYSROOT)/include/GLES2
	install -d $(SYSROOT)/include/EGL
	install -d $(SYSROOT)/include/KHR
#	install -d $(SYSROOT)/include/pvr2d
#	install -d $(SYSROOT)/include/wsegl

	install $(GRAPHICS_SDK_DIR)/include/OGLES/GLES/* $(SYSROOT)/include/GLES
	install $(GRAPHICS_SDK_DIR)/include/OGLES2/GLES2/* $(SYSROOT)/include/GLES2
	install $(GRAPHICS_SDK_DIR)/include/OGLES2/EGL/* $(SYSROOT)/include/EGL
	install $(GRAPHICS_SDK_DIR)/include/OGLES2/KHR/* $(SYSROOT)/include/KHR
	install $(GRAPHICS_SDK_DIR)/include/pvr2d/* $(SYSROOT)/include
	install $(GRAPHICS_SDK_DIR)/include/wsegl/* $(SYSROOT)/include

	install -d $(SYSROOT)/usr
	install -d $(SYSROOT)/usr/lib/
	install $(GRAPHICS_SDK_BASEDIR)/*.so $(SYSROOT)/usr/lib/
	@$(call touch)
# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/graphics_sdk.targetinstall:
	
	@$(call targetinfo)
	@$(call install_init,  graphics_sdk)
	@$(call install_fixup, graphics_sdk,PACKAGE,graphics-sdk)
	@$(call install_fixup, graphics_sdk,PRIORITY,optional)
	@$(call install_fixup, graphics_sdk,VERSION,$(GRAPHICS_SDK_VERSION))
	@$(call install_fixup, graphics_sdk,SECTION,base)
	@$(call install_fixup, graphics_sdk,AUTHOR,"Jan Weitzel <j.weitzel@phytec.de>")
	@$(call install_fixup, graphics_sdk,DEPENDS,)
	@$(call install_fixup, graphics_sdk,DESCRIPTION,missing)

#Don't use default rc init	
#	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(SYSROOT)/etc/init.d/rc.pvr, /etc/init.d/rc.pvr)
ifdef PTXCONF_GRAPHICS_SDK_STARTSCRIPT
	@$(call install_alternative, graphics_sdk, 0, 0, 0755, /etc/init.d/rc.pvr)
#init? systemd?	
ifdef PTXCONF_INITMETHOD_BBINIT
	@$(call install_link, graphics_sdk, ../init.d/rc.pvr, /etc/rc.d/S98pvr)
endif
endif

	@$(call install_alternative, graphics_sdk, 0, 0, 0644, /etc/powervr.ini)

#kernel modul
	$(KERNEL_PATH) $(KERNEL_ENV) $(MAKE) $(KERNEL_MAKEVARS) \
		-C $(KERNEL_DIR) \
		M=$(GRAPHICS_SDK_DIR)/GFX_Linux_KM \
		modules_install

# libs
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libGLES_CM.so, /usr/lib/libGLES_CM.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libGLES_CM.so.1.1.16.4117, /usr/lib/libGLES_CM.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libusc.so, /usr/lib/libusc.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libusc.so.1.1.16.4117, /usr/lib/libusc.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libGLESv2.so, /usr/lib/libGLESv2.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libGLESv2.so.1.1.16.4117, /usr/lib/libGLESv2.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libglslcompiler.so, \
		 /usr/lib/libglslcompiler.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libglslcompiler.so.1.1.16.4117, /usr/lib/libglslcompiler.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libOpenVG.so, /usr/lib/libOpenVG.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libOpenVG.so.1.1.16.4117, /usr/lib/libOpenVG.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libOpenVGU.so, /usr/lib/libOpenVGU.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libOpenVGU.so.1.1.16.4117, /usr/lib/libOpenVGU.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libIMGegl.so, /usr/lib/libIMGegl.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libIMGegl.so.1.1.16.4117, /usr/lib/libIMGegl.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libEGL.so, /usr/lib/libEGL.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libEGL.so.1.1.16.4117, /usr/lib/libEGL.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libpvr2d.so, /usr/lib/libpvr2d.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libpvr2d.so.1.1.16.4117, /usr/lib/libpvr2d.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libpvrPVR2D_BLITWSEGL.so, \
		/usr/lib/libpvrPVR2D_BLITWSEGL.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libpvrPVR2D_BLITWSEGL.so.1.1.16.4117, /usr/lib/libpvrPVR2D_BLITWSEGL.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libpvrPVR2D_FLIPWSEGL.so, \
		/usr/lib/libpvrPVR2D_FLIPWSEGL.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libpvrPVR2D_FLIPWSEGL.so.1.1.16.4117, /usr/lib/libpvrPVR2D_FLIPWSEGL.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libpvrPVR2D_FRONTWSEGL.so, \
		/usr/lib/libpvrPVR2D_FRONTWSEGL.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libpvrPVR2D_FRONTWSEGL.so.1.1.16.4117, /usr/lib/libpvrPVR2D_FRONTWSEGL.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libpvrPVR2D_LINUXFBWSEGL.so, \
		/usr/lib/libpvrPVR2D_LINUXFBWSEGL.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libpvrPVR2D_LINUXFBWSEGL.so.1.1.16.4117, /usr/lib/libpvrPVR2D_LINUXFBWSEGL.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libsrv_um.so, /usr/lib/libsrv_um.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libsrv_um.so.1.1.16.4117, /usr/lib/libsrv_um.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libsrv_init.so, /usr/lib/libsrv_init.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libsrv_init.so.1.1.16.4117, /usr/lib/libsrv_init.so)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/libPVRScopeServices.so, \
		/usr/lib/libPVRScopeServices.so.1.1.16.4117)
	@$(call install_link, graphics_sdk, libPVRScopeServices.so.1.1.16.4117, /usr/lib/libPVRScopeServices.so)

#executables
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/pvrsrvinit, /usr/local/bin/pvrsrvinit)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/sgx_init_test, /usr/local/bin/sgx_init_test)

ifdef PTXCONF_GRAPHICS_SDK_TEST
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/services_test, /usr/local/bin/services_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/sgx_blit_test, /usr/local/bin/sgx_blit_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/sgx_clipblit_test, /usr/local/bin/sgx_clipblit_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/gx_flip_test /usr/local/bin/sgx_flip_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/sgx_render_flip_test, \
		/usr/local/bin/sgx_render_flip_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/pvr2d_test, /usr/local/bin/pvr2d_test)

	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/gles1test1, /usr/local/bin/gles1test1)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/gles1_texture_stream, \
		/usr/local/bin/gles1_texture_stream)

	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/gles2test1, /usr/local/bin/gles2test1)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/glsltest1_vertshader.txt, \
		/usr/local/bin/glsltest1_vertshader.txt)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/glsltest1_fragshaderA.txt, \
		/usr/local/bin/glsltest1_fragshaderA.txt)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_BASEDIR)/glsltest1_fragshaderB.txt, \
		/usr/local/bin/glsltest1_fragshaderB.txt)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/gles2_texture_stream, \
		/usr/local/bin/gles2_texture_stream)

	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/ovg_unit_test, /usr/local/bin/ovg_unit_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_BASEDIR)/eglinfo, /usr/local/bin/eglinfo)
endif

ifdef PTXCONF_GRAPHICS_SDK_DEMOS
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_DIR)/targetfs/rundemos.sh, /opt/gfxsdkdemos/rundemos.sh)
	@$(call install_tree, graphics_sdk, 0, 0, $(SYSROOT)/opt/gfxsdkdemos/ogles, /opt/gfxsdkdemos)
	@$(call install_tree, graphics_sdk, 0, 0, $(SYSROOT)/opt/gfxsdkdemos/ogles2, /opt/gfxsdkdemos)
endif

	@$(call install_finish, graphics_sdk)

	@$(call touch)

# vim: syntax=make
